summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:36:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:36:05 -0600
commitdd844d7919e7f0f95c010378e7af1434ea904fff (patch)
tree50727ca63550e4397ff76e4d039c162e225d59fc /scripts
parent7df4eaa9f8fa84d2b859cc59d21134cc2334651c (diff)
downloadtdesdk-dd844d7919e7f0f95c010378e7af1434ea904fff.tar.gz
tdesdk-dd844d7919e7f0f95c010378e7af1434ea904fff.zip
Rename additional global TQt functions
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/kDebug2kdDebug.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/scripts/kDebug2kdDebug.sh b/scripts/kDebug2kdDebug.sh
index a238845e..2a08b610 100755
--- a/scripts/kDebug2kdDebug.sh
+++ b/scripts/kDebug2kdDebug.sh
@@ -1,5 +1,5 @@
## kDebug2kdDebug.sh
## Script to port from qDebug, kdebug, kDebugInfo etc. to kdDebug/kdWarning/...
## Example:
## kDebugInfo( [area,] "format %a - %b", arga, argb )
## becomes
@@ -27,7 +27,7 @@ while (<>)
#print "Reading line : " . $_ . "\n";
$statement .= $_;
}
- elsif ( /kdebug\s*\(/ || /kDebug[a-zA-Z]*\s*\(/ || /qDebug\s*/ || /qWarning\s*/ )
+ elsif ( /kdebug\s*\(/ || /kDebug[a-zA-Z]*\s*\(/ || /tqDebug\s*/ || /tqWarning\s*/ )
{
# Very old kdebug stuff :)
s/kdebug\s*\(\s*KDEBUG_INFO,/kDebugInfo\(/;
@@ -51,14 +51,14 @@ while (<>)
## 1 - Parse
if (s/(^.*kDebug[a-zA-Z]*)\s*\(\s*//) {
$line=$1; # has the indentation, //, and the kDebug* name
- } elsif (s/(^.*qDebug)\s*\(\s*// || s/(^.*qWarning)\s*\(\s*//) {
+ } elsif (s/(^.*tqDebug)\s*\(\s*// || s/(^.*tqWarning)\s*\(\s*//) {
$line=$1;
- } else { die "parse error on kDebug/qDebug/qWarning..."; }
+ } else { die "parse error on kDebug/tqDebug/tqWarning..."; }
$line=$1; # has the indentation, //, and the kDebug* name
$line =~ s/kDebugInfo/kdDebug/;
$line =~ s/kDebugArea/kdDebug/;
- $line =~ s/qDebug/kdDebug/;
- $line =~ s/qWarning/kdWarning/;
+ $line =~ s/tqDebug/kdDebug/;
+ $line =~ s/tqWarning/kdWarning/;
$line =~ s/kDebugWarning/kdWarning/;
$line =~ s/kDebugError/kdError/;
$line =~ s/kDebugFatal/kdFatal/;
@@ -72,7 +72,7 @@ while (<>)
$area = $1; # Store it
$line .= "(" . $area . ")";
} else
- { $line .= "()"; } # You can set an area here if converting qDebugs
+ { $line .= "()"; } # You can set an area here if converting tqDebugs
$arguments = ""; # for final test
$commented = 0;
@@ -1,5 +1,5 @@
## kDebug2kdDebug.sh
-## Script to port from qDebug, kdebug, kDebugInfo etc. to kdDebug/kdWarning/...
+## Script to port from tqDebug, kdebug, kDebugInfo etc. to kdDebug/kdWarning/...
## Example:
## kDebugInfo( [area,] "format %a - %b", arga, argb )